==> vtk-6.3.0-5-aarch64.pkg.tar.xz: vtk/vtkGeoAssignCoordinates.java <==
// java wrapper for vtkGeoAssignCoordinates object
//

package vtk;
import vtk.*;

public class vtkGeoAssignCoordinates extends vtkPassInputTypeAlgorithm
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetLongitudeArrayName_2(String id0);
  public void SetLongitudeArrayName(String id0)
    { SetLongitudeArrayName_2(id0); }

  private native String GetLongitudeArrayName_3();
  public String GetLongitudeArrayName()
    { return GetLongitudeArrayName_3(); }

  private native void SetLatitudeArrayName_4(String id0);
  public void SetLatitudeArrayName(String id0)
    { SetLatitudeArrayName_4(id0); }

  private native String GetLatitudeArrayName_5();
  public String GetLatitudeArrayName()
    { return GetLatitudeArrayName_5(); }

  private native void SetGlobeRadius_6(double id0);
  public void SetGlobeRadius(double id0)
    { SetGlobeRadius_6(id0); }

  private native double GetGlobeRadius_7();
  public double GetGlobeRadius()
    { return GetGlobeRadius_7(); }

  private native void SetTransform_8(vtkAbstractTransform id0);
  public void SetTransform(vtkAbstractTransform id0)
    { SetTransform_8(id0); }

  private native long GetTransform_9();
  public vtkAbstractTransform GetTransform() {
    long temp = GetTransform_9();

    if (temp == 0) return null;
    return (vtkAbstractTransform)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native void SetCoordinatesInArrays_10(boolean id0);
  public void SetCoordinatesInArrays(boolean id0)
    { SetCoordinatesInArrays_10(id0); }

  private native boolean GetCoordinatesInArrays_11();
  public boolean GetCoordinatesInArrays()
    { return GetCoordinatesInArrays_11(); }

  private native void CoordinatesInArraysOn_12();
  public void CoordinatesInArraysOn()
    { CoordinatesInArraysOn_12(); }

  private native void CoordinatesInArraysOff_13();
  public void CoordinatesInArraysOff()
    { CoordinatesInArraysOff_13(); }

  public vtkGeoAssignCoordinates() { super(); }

  public vtkGeoAssignCoordinates(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.2.0-9-aarch64.pkg.tar.xz: vtk/vtkGeoAssignCoordinates.java <==
// java wrapper for vtkGeoAssignCoordinates object
//

package vtk;
import vtk.*;

public class vtkGeoAssignCoordinates extends vtkPassInputTypeAlgorithm
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetLongitudeArrayName_2(String id0);
  public void SetLongitudeArrayName(String id0)
    { SetLongitudeArrayName_2(id0); }

  private native String GetLongitudeArrayName_3();
  public String GetLongitudeArrayName()
    { return GetLongitudeArrayName_3(); }

  private native void SetLatitudeArrayName_4(String id0);
  public void SetLatitudeArrayName(String id0)
    { SetLatitudeArrayName_4(id0); }

  private native String GetLatitudeArrayName_5();
  public String GetLatitudeArrayName()
    { return GetLatitudeArrayName_5(); }

  private native void SetGlobeRadius_6(double id0);
  public void SetGlobeRadius(double id0)
    { SetGlobeRadius_6(id0); }

  private native double GetGlobeRadius_7();
  public double GetGlobeRadius()
    { return GetGlobeRadius_7(); }

  private native void SetTransform_8(vtkAbstractTransform id0);
  public void SetTransform(vtkAbstractTransform id0)
    { SetTransform_8(id0); }

  private native long GetTransform_9();
  public vtkAbstractTransform GetTransform() {
    long temp = GetTransform_9();

    if (temp == 0) return null;
    return (vtkAbstractTransform)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetCoordinatesInArrays_10(boolean id0);
  public void SetCoordinatesInArrays(boolean id0)
    { SetCoordinatesInArrays_10(id0); }

  private native boolean GetCoordinatesInArrays_11();
  public boolean GetCoordinatesInArrays()
    { return GetCoordinatesInArrays_11(); }

  private native void CoordinatesInArraysOn_12();
  public void CoordinatesInArraysOn()
    { CoordinatesInArraysOn_12(); }

  private native void CoordinatesInArraysOff_13();
  public void CoordinatesInArraysOff()
    { CoordinatesInArraysOff_13(); }

  public vtkGeoAssignCoordinates() { super(); }

  public vtkGeoAssignCoordinates(long id) { super(id); }
  public native long   VTKInit();

}
